@@ -6,42 +6,42 @@
     <message>
         <location filename="../selectwnd.ui" line="14"/>
         <source>LXQt Mouse Theme Configuration</source>
-        <translation>LXQt Peles Motīva Konfigurācija</translation>
+        <translation>LXQt peles tēmas konfigurēšana</translation>
     </message>
     <message>
         <location filename="../selectwnd.ui" line="46"/>
         <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
-        <translation>Izvēlies kursora motīvu, kuru vēlies lietot (pārvieto uz priekšskatu lai izmēģinātu)&lt;b&gt;LXQt sesija ir jāpārstartē pēc šīm izmaiņām&lt;/b&gt;:</translation>
+        <translation>Izvēlies kursora tēmu, kuru vēlies lietot (novieto kursoru uz priekšskata laukuma, lai izmēģinātu)&lt;b&gt;Pēc šīm izmaiņām LXQt sesija ir jārestartē&lt;/b&gt;:</translation>
     </message>
     <message>
         <location filename="../selectwnd.ui" line="23"/>
         <source>&amp;Install New Theme...</source>
-        <translation>&amp;Pievienot jaunu motīvu...</translation>
+        <translation>&amp;Instalēt/uzstādīt/pievienot jaunu tēmu...</translation>
     </message>
     <message>
         <location filename="../selectwnd.ui" line="72"/>
         <source>LXQt session needs restart to view this change.</source>
-        <translation type="unfinished"></translation>
+        <translation>Šī iestatījuma maiņa stāsies spēkā pēc LXQt sesijas restarta.</translation>
     </message>
     <message>
         <location filename="../selectwnd.ui" line="91"/>
         <source>&amp;Remove Theme</source>
-        <translation>&amp;Dzēst motīvu</translation>
+        <translation>&amp;Dzēst/novākt tēmu</translation>
     </message>
     <message>
         <location filename="../selectwnd.ui" line="111"/>
         <source>Size</source>
-        <translation type="unfinished"></translation>
+        <translation>Izmērs</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="233"/>
+        <location filename="../selectwnd.cpp" line="231"/>
         <source>XCurTheme error</source>
-        <translation>XCurTheme kļūda</translation>
+        <translation>XCurTheme ķibele</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="234"/>
+        <location filename="../selectwnd.cpp" line="232"/>
         <source>You can&apos;t remove active theme!</source>
-        <translation>Aktīvo motīvu dzēst nav iespējams!</translation>
+        <translation>Aktīvo tēmu dzēst/novākt nav iespējams!</translation>
     </message>
 </context>
 <context>
@@ -54,7 +54,7 @@
     <message>
         <location filename="../warninglabel.ui" line="44"/>
         <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
-        <translation>LXQt nespēeja atrast nevienu kursora motīvu. X11 noklusējuma motīvs tiks lietots.  LXQt meklēja sekojošajās direktorijās:</translation>
+        <translation>LXQt nespēja atrast nevienu kursora tēmu/motīvu. Tiks izmantota X11 noklusējuma kursora tēma. LXQt meklēja šajās mapēs:</translation>
     </message>
     <message>
         <location filename="../warninglabel.ui" line="54"/>
