@@ -11,7 +11,7 @@
     <message>
         <location filename="../selectwnd.ui" line="46"/>
         <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
-        <translation>Vyberte vzhľad kurzora, ktorý chcete používať (vyskúšate prechodom myši na náhľad). &lt;b&gt;Po vykonaní zmeny je potrebné reštartovať sedenie LXQt&lt;/b&gt;:</translation>
+        <translation>Vyberte vzhľad kurzora, ktorý chcete používať (vyskúšate prechodom myši na náhľad). &lt;b&gt;Po vykonaní zmeny je potrebné reštartovať reláciu LXQt&lt;/b&gt;:</translation>
     </message>
     <message>
         <location filename="../selectwnd.ui" line="23"/>
@@ -21,7 +21,7 @@
     <message>
         <location filename="../selectwnd.ui" line="72"/>
         <source>LXQt session needs restart to view this change.</source>
-        <translation>Aby sa zmena prejavila, je potrebné reštartovať sedenie LXQt.</translation>
+        <translation>Aby sa zmena prejavila, je potrebné reštartovať reláciu LXQt.</translation>
     </message>
     <message>
         <location filename="../selectwnd.ui" line="91"/>
@@ -34,12 +34,12 @@
         <translation>Veľkosť</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="233"/>
+        <location filename="../selectwnd.cpp" line="231"/>
         <source>XCurTheme error</source>
         <translation>Chyba témy XCur</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="234"/>
+        <location filename="../selectwnd.cpp" line="232"/>
         <source>You can&apos;t remove active theme!</source>
         <translation>Nie je možné odstrániť práve používanú tému!</translation>
     </message>
