@@ -166,12 +166,12 @@
     <message>
         <location filename="../gtkconfig.ui" line="44"/>
         <source>GTK Style</source>
-        <translation type="unfinished"></translation>
+        <translation>GTK stil</translation>
     </message>
     <message>
         <location filename="../gtkconfig.ui" line="63"/>
         <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
-        <translation>Sæt GTK-temaer (GTK-konfigurationsfiler vil blive overskrevet!)</translation>
+        <translation>Angiv GTK temaer (GTK konfigurationsfiler vil blive overskrevet!)</translation>
     </message>
     <message>
         <location filename="../gtkconfig.ui" line="83"/>
@@ -188,9 +188,9 @@
         <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
 
 Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
-        <translation>For at forsøge ensartet tema, vælg enten lignende stil/tema (hvis tilgængelig) på tværs af alle lister, eller vælg &apos;gtk2&apos; Qt-stil (hvis tilgængelig) for at efterligne GTK-temaer.
+        <translation>For at forsøge ensartet tema, vælg enten lignende stil/tema (hvis tilgængelig) på tværs af alle lister, eller vælg &apos;gtk2&apos; Qt-stil (hvis tilgængelig) for at efterligne GTK temaer.
 
-Sørg for at &apos;xsettingsd&apos; er installeret, for at hjælpe GTK-programmer med at anvende tema med det samme.</translation>
+Sørg for at &apos;xsettingsd&apos; er installeret, for at hjælpe GTK programmer med at anvende tema med det samme.</translation>
     </message>
 </context>
 <context>
@@ -198,7 +198,7 @@ Sørg for at &apos;xsettingsd&apos; er installeret, for at hjælpe GTK-programme
     <message>
         <location filename="../iconthemeconfig.ui" line="14"/>
         <source>LXQt Appearance Configuration</source>
-        <translation>Konfiguraton af LXQt udseende</translation>
+        <translation>Konfiguration af LXQt udseende</translation>
     </message>
     <message>
         <location filename="../iconthemeconfig.ui" line="26"/>
@@ -225,8 +225,18 @@ Sørg for at &apos;xsettingsd&apos; er installeret, for at hjælpe GTK-programme
     </message>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="57"/>
-        <source>Override user-defined wallpaper</source>
-        <translation>Tilsidesæt brugerdefineret tapet</translation>
+        <source>Use wallpaper provided by theme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="94"/>
+        <source>(User Theme)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="182"/>
+        <source>Open theme folder</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -283,7 +293,7 @@ Sørg for at &apos;xsettingsd&apos; er installeret, for at hjælpe GTK-programme
     <message>
         <location filename="../main.cpp" line="118"/>
         <source>GTK Style</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">GTK stil</translation>
     </message>
 </context>
 <context>
