@@ -225,8 +225,18 @@ Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply the
     </message>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="57"/>
-        <source>Override user-defined wallpaper</source>
-        <translation>דריסת רקע שולחן העבודה שהוגדר על ידי המשתמש</translation>
+        <source>Use wallpaper provided by theme</source>
+        <translation>שימוש ברקע שמספקת ערכת הנושא</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="94"/>
+        <source>(User Theme)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="182"/>
+        <source>Open theme folder</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
