@@ -225,8 +225,18 @@ Uvjeri se da je „xsettingsd” instaliran, koji GTK programima pomaže trenutn
     </message>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="57"/>
-        <source>Override user-defined wallpaper</source>
-        <translation>Nadjačaj korisničku sliku pozadine</translation>
+        <source>Use wallpaper provided by theme</source>
+        <translation>Koristi sliku pozadine koju pruža tema</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="94"/>
+        <source>(User Theme)</source>
+        <translation>(Korisnička tema)</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="182"/>
+        <source>Open theme folder</source>
+        <translation>Otvori mapu tema</translation>
     </message>
 </context>
 <context>
