@@ -166,7 +166,7 @@
     <message>
         <location filename="../gtkconfig.ui" line="44"/>
         <source>GTK Style</source>
-        <translation type="unfinished"></translation>
+        <translation>GTK stilius</translation>
     </message>
     <message>
         <location filename="../gtkconfig.ui" line="63"/>
@@ -225,8 +225,18 @@ Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply the
     </message>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="57"/>
-        <source>Override user-defined wallpaper</source>
-        <translation>Nustelbti naudotojo apibrėžtą darbalaukio foną</translation>
+        <source>Use wallpaper provided by theme</source>
+        <translation>Naudoti apipavidalinimo teikiamą darbalaukio foną</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="94"/>
+        <source>(User Theme)</source>
+        <translation>(Naudotojo apipavidalinimas)</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="182"/>
+        <source>Open theme folder</source>
+        <translation>Atverti apipavidalinimo aplanką</translation>
     </message>
 </context>
 <context>
@@ -283,7 +293,7 @@ Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply the
     <message>
         <location filename="../main.cpp" line="118"/>
         <source>GTK Style</source>
-        <translation type="unfinished"></translation>
+        <translation>GTK stilius</translation>
     </message>
 </context>
 <context>
