@@ -166,7 +166,7 @@
     <message>
         <location filename="../gtkconfig.ui" line="44"/>
         <source>GTK Style</source>
-        <translation type="unfinished"></translation>
+        <translation>Styl GTK</translation>
     </message>
     <message>
         <location filename="../gtkconfig.ui" line="63"/>
@@ -225,8 +225,18 @@ Upewnij się, że „xsettingsd” jest zainstalowany, aby aplikacje GTK zmienia
     </message>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="57"/>
-        <source>Override user-defined wallpaper</source>
-        <translation>Zastąp tło pulpitu wybrane przez użytkownika</translation>
+        <source>Use wallpaper provided by theme</source>
+        <translation>Użyj tapety dostarczonej przez motyw</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="94"/>
+        <source>(User Theme)</source>
+        <translation>(Motyw Użytkownika)</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="182"/>
+        <source>Open theme folder</source>
+        <translation>Otwórz katalog z motywem</translation>
     </message>
 </context>
 <context>
@@ -283,7 +293,7 @@ Upewnij się, że „xsettingsd” jest zainstalowany, aby aplikacje GTK zmienia
     <message>
         <location filename="../main.cpp" line="118"/>
         <source>GTK Style</source>
-        <translation type="unfinished"></translation>
+        <translation>Styl GTK</translation>
     </message>
 </context>
 <context>
