@@ -225,8 +225,18 @@ Verifique se o pacote &apos;xsettingsd&apos; está instalado, para permitir com
     </message>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="57"/>
-        <source>Override user-defined wallpaper</source>
-        <translation>Substituir o papel de parede definido pelo usuário</translation>
+        <source>Use wallpaper provided by theme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="94"/>
+        <source>(User Theme)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="182"/>
+        <source>Open theme folder</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
