@@ -29,6 +29,14 @@
         <translation>     ❷ Solo il secondario</translation>
     </message>
 </context>
+<context>
+    <name>LoadSettings</name>
+    <message>
+        <location filename="../loadsettings.cpp" line="97"/>
+        <source>Default monitor settings has been applied. If you want change monitors settings, please, use lxqt-config-monitor.</source>
+        <translation>Sono state applicate le impostazioni predefinite per il monitor. Per modificare le impostazioni usare lxqt-config-monitor.</translation>
+    </message>
+</context>
 <context>
     <name>ManageSavedSettings</name>
     <message>
@@ -57,44 +65,44 @@
         <translation>Applica</translation>
     </message>
     <message>
-        <location filename="../managesavedsettings.cpp" line="64"/>
+        <location filename="../managesavedsettings.cpp" line="62"/>
         <source>None</source>
         <translation>Nessuna</translation>
     </message>
     <message>
-        <location filename="../managesavedsettings.cpp" line="67"/>
+        <location filename="../managesavedsettings.cpp" line="65"/>
         <source>Left</source>
         <translation>Sinistra</translation>
     </message>
     <message>
-        <location filename="../managesavedsettings.cpp" line="70"/>
+        <location filename="../managesavedsettings.cpp" line="68"/>
         <source>Inverted</source>
         <translation>Inversiti</translation>
     </message>
     <message>
-        <location filename="../managesavedsettings.cpp" line="73"/>
+        <location filename="../managesavedsettings.cpp" line="71"/>
         <source>Right</source>
         <translation>Destra</translation>
     </message>
     <message>
-        <location filename="../managesavedsettings.cpp" line="77"/>
-        <location filename="../managesavedsettings.cpp" line="78"/>
+        <location filename="../managesavedsettings.cpp" line="75"/>
+        <location filename="../managesavedsettings.cpp" line="76"/>
         <source>True</source>
         <translation>Vero</translation>
     </message>
     <message>
-        <location filename="../managesavedsettings.cpp" line="77"/>
-        <location filename="../managesavedsettings.cpp" line="78"/>
+        <location filename="../managesavedsettings.cpp" line="75"/>
+        <location filename="../managesavedsettings.cpp" line="76"/>
         <source>False</source>
         <translation>Falso</translation>
     </message>
     <message>
-        <location filename="../managesavedsettings.cpp" line="140"/>
+        <location filename="../managesavedsettings.cpp" line="136"/>
         <source>Name</source>
         <translation>Nome</translation>
     </message>
     <message>
-        <location filename="../managesavedsettings.cpp" line="140"/>
+        <location filename="../managesavedsettings.cpp" line="136"/>
         <source>Name:</source>
         <translation>Nome:</translation>
     </message>
@@ -120,17 +128,17 @@
         <translation>Impostazioni</translation>
     </message>
     <message>
-        <location filename="../monitorsettingsdialog.cpp" line="111"/>
+        <location filename="../monitorsettingsdialog.cpp" line="105"/>
         <source>Fast Menu</source>
         <translation>Opzioni veloci</translation>
     </message>
     <message>
-        <location filename="../monitorsettingsdialog.cpp" line="115"/>
+        <location filename="../monitorsettingsdialog.cpp" line="109"/>
         <source>Set position</source>
         <translation>Imposta la posizione</translation>
     </message>
     <message>
-        <location filename="../monitorsettingsdialog.cpp" line="247"/>
+        <location filename="../monitorsettingsdialog.cpp" line="228"/>
         <source>Advanced settings</source>
         <translation>Impostazioni avanzate</translation>
     </message>
@@ -198,69 +206,69 @@
         <translation>Informazioni sullo schermo</translation>
     </message>
     <message>
-        <location filename="../monitorwidget.cpp" line="135"/>
+        <location filename="../monitorwidget.cpp" line="128"/>
         <source>Name: %1
 </source>
         <translation>Nome: %1
 </translation>
     </message>
     <message>
-        <location filename="../monitorwidget.cpp" line="136"/>
+        <location filename="../monitorwidget.cpp" line="129"/>
         <source>Vendor: %1
 </source>
         <translation>Produttore: %1
 </translation>
     </message>
     <message>
-        <location filename="../monitorwidget.cpp" line="137"/>
+        <location filename="../monitorwidget.cpp" line="130"/>
         <source>Serial: %1
 </source>
         <translation>Seriale: %1
 </translation>
     </message>
     <message>
-        <location filename="../monitorwidget.cpp" line="138"/>
+        <location filename="../monitorwidget.cpp" line="131"/>
         <source>Display size: %1cm x %2cm
 </source>
         <translation>Dimensioni dello schermo: %1cm x %2cm
 </translation>
     </message>
     <message>
-        <location filename="../monitorwidget.cpp" line="139"/>
+        <location filename="../monitorwidget.cpp" line="132"/>
         <source>Serial number: %1
 </source>
         <translation>Numero di serie: %1
 </translation>
     </message>
     <message>
-        <location filename="../monitorwidget.cpp" line="140"/>
+        <location filename="../monitorwidget.cpp" line="133"/>
         <source>EISA device ID: %1
 </source>
         <translation>ID di dispositivo EISA: %1
 </translation>
     </message>
     <message>
-        <location filename="../monitorwidget.cpp" line="161"/>
+        <location filename="../monitorwidget.cpp" line="153"/>
         <source>None</source>
         <translation>Nessuna</translation>
     </message>
     <message>
-        <location filename="../monitorwidget.cpp" line="162"/>
+        <location filename="../monitorwidget.cpp" line="154"/>
         <source>Left</source>
         <translation>Sinistra</translation>
     </message>
     <message>
-        <location filename="../monitorwidget.cpp" line="163"/>
+        <location filename="../monitorwidget.cpp" line="155"/>
         <source>Right</source>
         <translation>Destra</translation>
     </message>
     <message>
-        <location filename="../monitorwidget.cpp" line="164"/>
+        <location filename="../monitorwidget.cpp" line="156"/>
         <source>Inverted</source>
         <translation>Inversa</translation>
     </message>
     <message>
-        <location filename="../monitorwidget.cpp" line="255"/>
+        <location filename="../monitorwidget.cpp" line="244"/>
         <source>%1 Hz</source>
         <translation>%1 Hz</translation>
     </message>
@@ -276,12 +284,12 @@
 <context>
     <name>SaveSettings</name>
     <message>
-        <location filename="../savesettings.cpp" line="82"/>
+        <location filename="../savesettings.cpp" line="87"/>
         <source>Name</source>
         <translation>Nome</translation>
     </message>
     <message>
-        <location filename="../savesettings.cpp" line="82"/>
+        <location filename="../savesettings.cpp" line="87"/>
         <source>Name:</source>
         <translation>Nome:</translation>
     </message>
@@ -299,7 +307,7 @@
         <translation>Vuoi mantenere questa configurazione?</translation>
     </message>
     <message numerus="yes">
-        <location filename="../timeoutdialog.cpp" line="65"/>
+        <location filename="../timeoutdialog.cpp" line="63"/>
         <source>%n second(s) remaining</source>
         <translation>
             <numerusform>%1 secondo rimanente</numerusform>
