@@ -34,7 +34,7 @@
     <message>
         <location filename="../loadsettings.cpp" line="97"/>
         <source>Default monitor settings has been applied. If you want change monitors settings, please, use lxqt-config-monitor.</source>
-        <translation type="unfinished"></translation>
+        <translation>Používam predvolené nastavenie monitora. Ak si prajete zmeniť nastavenie monitora, použite prosím lxqt-config-monitor.</translation>
     </message>
 </context>
 <context>
@@ -230,7 +230,7 @@
         <location filename="../monitorwidget.cpp" line="131"/>
         <source>Display size: %1cm x %2cm
 </source>
-        <translation>Veľkosť obrazovky: %1  x %2 cm
+        <translation>Veľkosť obrazovky: %1 x %2 cm
 </translation>
     </message>
     <message>
