@@ -34,7 +34,7 @@
     <message>
         <location filename="../loadsettings.cpp" line="97"/>
         <source>Default monitor settings has been applied. If you want change monitors settings, please, use lxqt-config-monitor.</source>
-        <translation type="unfinished"></translation>
+        <translation>Застосовано типові налаштування монітора. Якщо ви хочете змінити налаштування моніторів, використовуйте lxqt-config-monitor.</translation>
     </message>
 </context>
 <context>
@@ -209,37 +209,43 @@
         <location filename="../monitorwidget.cpp" line="128"/>
         <source>Name: %1
 </source>
-        <translation>Назва: %1</translation>
+        <translation>Назва: %1
+</translation>
     </message>
     <message>
         <location filename="../monitorwidget.cpp" line="129"/>
         <source>Vendor: %1
 </source>
-        <translation>Виробник: %1</translation>
+        <translation>Виробник: %1
+</translation>
     </message>
     <message>
         <location filename="../monitorwidget.cpp" line="130"/>
         <source>Serial: %1
 </source>
-        <translation>Серія: %1</translation>
+        <translation>Серійний номер: %1
+</translation>
     </message>
     <message>
         <location filename="../monitorwidget.cpp" line="131"/>
         <source>Display size: %1cm x %2cm
 </source>
-        <translation>Розмір дисплею: %1см x %2см</translation>
+        <translation>Розмір дисплея: %1см x %2см
+</translation>
     </message>
     <message>
         <location filename="../monitorwidget.cpp" line="132"/>
         <source>Serial number: %1
 </source>
-        <translation>Серійний номер: %1</translation>
+        <translation>Серійний номер: %1
+</translation>
     </message>
     <message>
         <location filename="../monitorwidget.cpp" line="133"/>
         <source>EISA device ID: %1
 </source>
-        <translation>ID пристрою EISA: %1</translation>
+        <translation>ID пристрою EISA: %1
+</translation>
     </message>
     <message>
         <location filename="../monitorwidget.cpp" line="153"/>
@@ -280,12 +286,12 @@
     <message>
         <location filename="../savesettings.cpp" line="87"/>
         <source>Name</source>
-        <translation type="unfinished">Назва</translation>
+        <translation>Назва</translation>
     </message>
     <message>
         <location filename="../savesettings.cpp" line="87"/>
         <source>Name:</source>
-        <translation type="unfinished">Назва:</translation>
+        <translation>Назва:</translation>
     </message>
 </context>
 <context>
@@ -298,15 +304,15 @@
     <message>
         <location filename="../timeoutdialog.ui" line="46"/>
         <source>Are the current settings OK for you?</source>
-        <translation>Чи теперішні налаштування Вас влаштовують?</translation>
+        <translation>Чи влаштовують вас поточні налаштування?</translation>
     </message>
     <message numerus="yes">
         <location filename="../timeoutdialog.cpp" line="63"/>
         <source>%n second(s) remaining</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Залишилась %n секунда</numerusform>
+            <numerusform>Залишилось %n секунди</numerusform>
+            <numerusform>Залишилось %n секунд</numerusform>
         </translation>
     </message>
 </context>
